@@ -8,15 +8,15 @@ make it hard to implement new features.
 
 """
 
-
 from . import environ  # noqa: F401
 from . import formatting  # noqa: F401
-from . import logic  # noqa: F401
-from . import type_aliases  # noqa: F401
+from . import math  # noqa: F401
+from . import security  # noqa: F401
+from . import types  # noqa: F401
 from . import units  # noqa: F401
 from .configuration import *  # noqa: F401, F403
 from .data_type import *  # noqa: F401, F403
 from .exceptions import *  # noqa: F401, F403
 from .files import *  # noqa: F401, F403
 from .inform import *  # noqa: F401, F403
-from .type_normalization import *  # noqa: F401, F403
+from .normalization import *  # noqa: F401, F403
