@@ -4,7 +4,7 @@ import astropy.units as u
 import ogameasure
 
 from ... import utils
-from ...core import logic
+from ...core.security import busy
 from .encoder_base import Encoder
 
 
@@ -17,11 +17,11 @@ class ND287(Encoder):
     Identifier = "port"
 
     @utils.skip_on_simulator
-    def __init__(self, **kwargs) -> None:
+    def __init__(self) -> None:
         self.io = ogameasure.HEIDENHAIN.ND287(self.Config.port)
 
     def get_reading(self) -> u.Quantity:
-        with logic.busy(self, "busy"):
+        with busy(self, "busy"):
             raw = self.io.output_position_display_value()
         return float(raw.strip(b"\x02\x00\r\n").decode()) << u.deg  # type: ignore
 
