@@ -18,7 +18,7 @@ class XFFTS(Spectrometer):
 
     Identifier = "host"
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self) -> None:
         self.logger = get_logger(self.__class__.__name__)
 
         self.host = self.Config.host
