@@ -3,7 +3,7 @@ import time
 import astropy.units as u
 import ogameasure
 
-from ...core import logic
+from ...core.security import busy
 from .thermometer_base import Thermometer
 
 
@@ -14,12 +14,12 @@ class Model218(Thermometer):
 
     Identifier = "usb_port"
 
-    def __init__(self, **kwargs) -> None:
+    def __init__(self) -> None:
         self.thermometer = ogameasure.Lakeshore.model218_usb(self.Config.usb_port)
 
     def get_temp(self, id: str) -> u.Quantity:
         ch = self.Config.channel[id]
-        with logic.busy(self, "busy"):
+        with busy(self, "busy"):
             data = self.thermometer.kelvin_reading_query(ch)
             time.sleep(0.1)
             return data * u.K
