@@ -1,7 +1,7 @@
 import astropy.units as u
 import ogameasure
 
-from ...core import logic
+from ...core.security import busy
 from .vacuum_gauge_base import VacuumGauge
 
 
@@ -12,13 +12,13 @@ class TPG261(VacuumGauge):
 
     Identifier = "host"
 
-    def __init__(self, **kwargs):
+    def __init__(self):
         com = ogameasure.ethernet(self.Config.host, self.Config.port)
         self.io = ogameasure.Pfeiffer.tpg261_lan(com)
         self.io.pres_unit_pa()
 
     def get_pressure(self) -> u.Quantity:
-        with logic.busy(self, "busy"):
+        with busy(self, "busy"):
             return self.io.pressure() * u.Pa
 
     def finalize(self):
