@@ -2,8 +2,8 @@ import time
 from pathlib import Path
 from typing import Optional
 
-from .. import get_logger
-from ..core.type_aliases import TextLike
+from ..core import get_logger
+from ..core.types import TextLike
 from .writer_base import Writer
 
 
